# :assert

tst "assert(nil) raises" do
  assert_raises Tst::Failure do
    assert nil
  end
end

tst "assert(false) raises" do
  assert_raises Tst::Failure do
    assert false
  end
end

tst "assert(true) does NOT raise" do
  assert true
end

tst "assert(0) does NOT raise" do
  assert 0
end

tst "assert('') does NOT raise" do
  assert 'asdf'
end


# :assert_equal

tst "assert_equal raises if things are NOT ==" do
  assert_raises Tst::Failure do
    assert_equal "Arthur Dent", "Ford Prefect"
  end
end

tst "assert_equal does NOT raise if things are ==" do
  assert_equal 42, 42
end


# :assert_raises

tst "assert_raises raises if its block does NOT raise something" do
  assert_raises Tst::Failure do
    assert_raises { }
  end
end

tst "assert_raises raises if its block doesn't raise the right thing" do
  assert_raises Tst::Failure do
    assert_raises(NameError) { raise RuntimeError }
  end
end

tst "assert_raises does NOT raise if it gets the expected error" do
  assert_raises(NameError) { raise NameError }
end

tst "assert_raises does NOT raise on expected error subclass" do
  assert_raises(ArgumentError) { raise Class.new(ArgumentError) }
end

tst "assert_raises returns the raised exception" do
  error = assert_raises(NameError) { raise NameError.new('lkjlkjlkj') }
  assert_equal 'lkjlkjlkj', error.message
end
