require 'stringio'

def tst_runner_output(glob, expected)
  tst "running #{glob}" do
    io = StringIO.new('')
    reporter = Tst::Reporters::Plain.new(io)
    Tst.run glob, :reporter => reporter
    assert_equal expected, io.string.gsub(/0\.\d+/, 'X.XXX')
  end
end

tst_runner_output "test/fixtures/success.rb", <<-end
.
1 passed, 0 failed, 0 raised in X.XXXs
end

tst_runner_output "test/fixtures/failure.rb", <<-end
F
F1: Failure: Truthiness - "one failing test"
  exp: "not false or nil"
  got: false
* test/fixtures/failure.rb:2
* test/fixtures/failure.rb:1
* test/plain_reporter.rb:7
* test/plain_reporter.rb:4
* test/plain_reporter.rb:17

0 passed, 1 failed, 0 raised in X.XXXs
end

tst_runner_output "test/fixtures/exception.rb", <<-end
E
E1: #<RuntimeError: I'm a teapot> - "one 'exceptional' test"
* test/fixtures/exception.rb:2
* test/fixtures/exception.rb:1
* test/plain_reporter.rb:7
* test/plain_reporter.rb:4
* test/plain_reporter.rb:31

0 passed, 0 failed, 1 raised in X.XXXs
end

tst_runner_output "test/fixtures/{exception,success,failure}.rb", <<-end
E.F
F1: Failure: Truthiness - "one failing test"
  exp: "not false or nil"
  got: false
* test/fixtures/failure.rb:2
* test/fixtures/failure.rb:1
* test/plain_reporter.rb:7
* test/plain_reporter.rb:4
* test/plain_reporter.rb:43

E1: #<RuntimeError: I'm a teapot> - "one 'exceptional' test"
* test/fixtures/exception.rb:2
* test/fixtures/exception.rb:1
* test/plain_reporter.rb:7
* test/plain_reporter.rb:4
* test/plain_reporter.rb:43

1 passed, 1 failed, 1 raised in X.XXXs
end

tst_runner_output "test/fixtures/does_not_exist.rb", <<-end

0 passed, 0 failed, 0 raised in X.XXXs
end

